@@ -2,7 +2,7 @@ package Layout::Manager;
 use Moose;
 
 our $AUTHORITY = 'cpan:GPHAT';
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 use MooseX::AttributeHelpers;
 
@@ -146,29 +146,21 @@ component, as those components need to be ignored.
 
 =head1 METHODS
 
-=over 4
-
-=item I<do_layout>
+=head2 do_layout
 
 Lays out this manager's components in the specified container.
 
-=back
-
 =head1 AUTHOR
 
 Cory Watson, C<< <gphat@cpan.org> >>
 
-Infinity Interactive, L<http://www.iinteractive.com>
-
 =head1 SEE ALSO
 
 perl(1), L<Graphics::Primitive>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
+Copyright 2008 - 2009 Cory G Watson
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
